@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::VERSION = '0.23';
+$Spreadsheet::ParseXLSX::VERSION = '0.24';
 use strict;
 use warnings;
 use 5.008;
@@ -52,13 +52,20 @@ sub parse {
         $workbook->{File} = undef;
         $workbook->{__tempfile} = $file;
     }
+    elsif (ref($file) eq 'SCALAR') {
+        open my $fh, '+<', $file
+            or die "Can't create filehandle from memory data";
+        $zip->readFromFileHandle($fh) == Archive::Zip::AZ_OK
+            or die "Can't open scalar ref as a zip file";
+        $workbook->{File} = undef;
+    }
     elsif (!ref($file)) {
         $zip->read($file) == Archive::Zip::AZ_OK
             or die "Can't open file '$file' as a zip file";
         $workbook->{File} = $file;
     }
     else {
-        die "Argument to 'new' must be a filename or open filehandle";
+        die "Argument to 'new' must be a filename, open filehandle, or scalar ref";
     }
 
     return $self->_parse_workbook($zip, $workbook, $formatter);
@@ -74,6 +81,9 @@ sub _check_signature {
         $file->read($signature, 2);
         $file->seek(-2, IO::File::SEEK_CUR);
     }
+    elsif (ref($file) eq 'SCALAR') {
+        $signature = substr($$file, 0, 2);
+    }
     elsif (!ref($file)) {
         my $fh = IO::File->new($file, 'r');
         $fh->read($signature, 2);
@@ -1093,7 +1103,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
